@@ -25,7 +25,8 @@ import numpy as np
 from typing import List, Union, Optional, Dict, Tuple
 
 from rdkit import Chem
-from rdkit.Chem import rdFMCS, AllChem
+from rdkit.Chem import rdFMCS, AllChem, EnumerateStereoisomers
+from rdkit.Chem.MolStandardize import rdMolStandardize
 
 from ._victor_common import _VictorCommon
 from ..m_rmsd import mRMSD
@@ -501,12 +502,12 @@ class _VictorUtils(_VictorCommon):
             fd = json.load(open(fragjson))
             self.smiles = fd['smiles']
             self.is_covalent = True if '*' in self.smiles else False
-            self.monster.place(mol=self.mol,
-                               attachment=None,
-                               merging_mode='off')
+            self.monster = Monster(self.hits)
+            # self.monster.place(mol=self.mol,
+            #                    attachment=None,
+            #                    merging_mode='off')
             self.monster.positioned_mol = self.mol
             self.monster.positioned_mol.SetProp('_Origins', json.dumps(fd['origin']))
-
         else:
             self.is_covalent = None
             self.smiles = ''
@@ -536,9 +537,10 @@ class _VictorUtils(_VictorCommon):
             self.mrmsd.mrmsd = md["mRMSD"]
             self.mrmsd.rmsds = md["RMSDs"]
             self.igor = Igor.from_pdbfile(
-                pdbfile=os.path.join(self.work_path, self.long_name, self.long_name + '.holo_minimised.pdb'),
-                params_file=os.path.join(self.work_path, self.long_name, self.long_name + '.params'),
-                constraint_file=os.path.join(self.work_path, self.long_name, self.long_name + '.con'))
+                pdbfile=os.path.join(folder, self.long_name + '.holo_minimised.pdb'),
+                params_file=os.path.join(folder, self.long_name + '.params'),
+                constraint_file=os.path.join(folder, self.long_name + '.con'))
+            self.minimized_mol = victor._fix_minimized()  # otherwise it lacks PDBInfo, such as names
         else:
             self.energy_score = {'ligand_ref2015': {'total_score': float('nan')},
                                  'unbound_ref2015': {'total_score': float('nan')}}
@@ -551,9 +553,48 @@ class _VictorUtils(_VictorCommon):
             self.minimized_mol = None
         return self
 
-    # =================== Laboratory ===================================================================================
+    # =================== Guess ===================================================================================
 
     @classmethod
-    def laboratory(cls, entries: List[dict], cores: int = 1):
-        raise NotImplementedError('Not yet written.')
-        pass
+    def get_isomers(cls, mol: Chem.Mol) -> List[Chem.Mol]:
+        """
+        For placement operations in particular it is important to differentiate the
+        isomers. Therefore requiring multiple victor calls.
+        """
+        enumerate_tautomers = rdMolStandardize.TautomerEnumerator().Enumerate
+        enumerate_stereoisomers = EnumerateStereoisomers.EnumerateStereoisomers
+        return [tauto for stereo in enumerate_stereoisomers(mol)
+                for tauto in enumerate_tautomers(stereo)
+                ]
+
+    def get_isomers_smiles(cls, smiles: str) -> List[str]:
+        """
+        Same as `get_isomers`, but with smiles.
+        """
+        return list(map(Chem.MolToSmiles, cls.get_isomers(Chem.MolFromSmiles(smiles))))
+
+    @classmethod
+    def guess_warhead(cls, smiles: str) -> Tuple[str, str]:
+        """
+        Going backwards by guessing what the warhead is.
+        Normally there'd be better data handling so no guessing
+        """
+        if not smiles or not isinstance(smiles, str):
+            return '', 'noncovalent'
+        if '*' not in smiles:
+            return smiles, 'noncovalent'
+        mol = Chem.MolFromSmiles(smiles)
+        warhead_defs = []
+        for warhead_def in cls.warhead_definitions:
+            if mol.HasSubstructMatch(Chem.MolFromSmiles(warhead_def['covalent'])):
+                warhead_defs.append(warhead_def)
+        if not warhead_defs:
+            cls.journal.warning(f'Could not match {smiles} to a warhead definition in `Victor.warhead_definitions`')
+            return smiles.replace('*', 'O'), 'noncovalent'
+        # most complex one first!
+        warhead_def = sorted(warhead_defs, key=lambda d: -len(d['covalent_atomnames']))[0]
+        unrxn_mols = AllChem.ReplaceSubstructs(mol=mol,
+                                               query=Chem.MolFromSmiles(warhead_def['covalent']),
+                                               replacement=Chem.MolFromSmiles(warhead_def['noncovalent'])
+                                               )  # noqa it is filled.
+        return Chem.MolToSmiles(unrxn_mols[0]), warhead_def['name']
